@@ -68,6 +68,9 @@ where
         location: L,
         range: R,
     ) -> BoxFuture<'a, Result<ChunkStream, CondowError>>;
+
+    /// Get the size of a file at the BLOB location
+    fn get_size<'a>(&'a self, location: L) -> BoxFuture<'a, Result<u64, CondowError>>;
 }
 
 /// The CONcurrent DOWnloader
@@ -167,7 +170,7 @@ impl<C: CondowClient> Condow<C> {
     }
 
     /// Get the size of a file at the given location
-    pub async fn get_size(&self, location: C::Location) -> Result<usize, CondowError> {
+    pub async fn get_size(&self, location: C::Location) -> Result<u64, CondowError> {
         self.client.get_size(location).await
     }
 }
@@ -191,6 +194,10 @@ where
     ) -> BoxFuture<'a, Result<ChunkStream, CondowError>> {
         Box::pin(self.download_chunks(location, range))
     }
+
+    fn get_size<'a>(&'a self, location: C::Location) -> BoxFuture<'a, Result<u64, CondowError>> {
+        Box::pin(self.get_size(location))
+    }
 }
 
 /// A composite struct of a stream and a [Reporter]
